* 总部地址：上海市杨浦区政府路 18 号 901 室，200433
* 电话号码：+86-21-61431590
* 电子邮件：[info@daocloud.io](mailto:info@daocloud.io?subject=FROM_DOCS_PAGES)
* 媒体垂询：[media@daocloud.io](mailto:media@daocloud.io?subject=FROM_DOCS_PAGES)
* Logo 标示：[点击下载](http://7xo6wp.dl1.z0.glb.clouddn.com/daocloud_press_kit.zip)
* [新浪微博](http://weibo.com/daocloud)
* [Facebook](https://www.facebook.com/pages/DaoCloudio/794434853974192)
* [Twitter](https://twitter.com/DaoCloudIO)
* [LinkedIn](https://www.linkedin.com/company/daocloud-network-technology-co-ltd-)
